@@ -40,7 +40,7 @@ options(rmoo.description = list(Title = "Multi-Objective Optimization in R",
           `Authors@R` = "c(person(\"Francisco\", \"Benitez\",
                                 email = \"benitezfj94@gmail.com\",
                                 role = c(\"aut\", \"cre\")),
-                             person(\"Diego\", \"Pinto Roa\",
+                             person(\"Diego P.\", \"Pinto-Roa\",
                                 email = \"dpinto@pol.una.py\",
                                 role = c(\"aut\"),
                                 comment = c(ORCID = \"0000-0003-2479-9876\")))",
